.. ryvencore documentation master file, created by
   sphinx-quickstart on Wed Nov 24 09:44:03 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

`ryvencore` |version|
=====================================

.. toctree::
   :maxdepth: 2

   ryvencore


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
